============================
Henson-Sentry |build status|
============================

.. |build status| image:: https://travis-ci.org/dirn/Henson-Sentry.svg?branch=master
   :target: https://travis-ci.org/dirn/Henson-Sentry

A library for integrating Sentry into a Henson application.

* `Documentation <https://henson-sentry.rtfd.org>`_
* `Installation <https://henson-sentry.readthedocs.org/en/latest/#installation>`_
* `Changelog <https://henson-sentry.readthedocs.org/en/latest/changes.html>`_
* `Source <https://github.com/dirn/Henson-Sentry>`_
